==> haskell-persistent-postgresql-2.13.5.2-13-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.2
visibility:           public
id:                   persistent-postgresql-2.13.5.2-JLhNTtrmNj16M5Nlk0QttR
key:                  persistent-postgresql-2.13.5.2-JLhNTtrmNj16M5Nlk0QttR
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  e86c33aea33b6e396b88e93aa3af2745
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.2-JLhNTtrmNj16M5Nlk0QttR
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q containers-0.6.7
    monad-logger-0.3.42-8CskNFmll7427ag5mqbmhY mtl-2.3.1
    persistent-2.14.5.2-GJyCnJ8J8PvBVRSOBxUsv4
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    postgresql-simple-0.6.5.1-Gozoz9g4mEG8gb8UHAaYdY
    resource-pool-0.2.3.2-3uIbkUYrHNdAfRBpvdjlDL
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx
    string-conversions-0.4.0.1-3kMZcJjj5P5Da5apuKM9D9 text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vault-0.3.1.5-1WesiFbrgeBJ6Pz5D8LxKa

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-postgresql-2.13.5.2-14-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.2
visibility:           public
id:                   persistent-postgresql-2.13.5.2-HIvDP08bxjK23S5rCYsGDg
key:                  persistent-postgresql-2.13.5.2-HIvDP08bxjK23S5rCYsGDg
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  3e227bb7112563f57877730e4355f711
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.2-HIvDP08bxjK23S5rCYsGDg
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w mtl-2.3.1
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    postgresql-simple-0.6.5.1-5JYEchWIWjWK7gvgJTbLy9
    resource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    string-conversions-0.4.0.1-LTGnXQU7F9LF7QuuvvXPma text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
